Try traits for core::hash.
Note that BuildHasher isn’t implemented because each call to
build_hasher should return identical values.
Hasher also was not given a Try variant as I can see no real use for it (and as it
complicates automatic implementations), , but if there’s good reason for one it’ll be added.